@@ -21,9 +21,10 @@ import urlparse
 import zipfile
 import xml.dom.minidom
 import mimetypes
+import codecs
 
 PROG = os.path.basename(os.path.splitext(__file__)[0])
-VERSION = '8.6.9'
+VERSION = '8.6.10'
 
 # AsciiDoc global configuration file directory.
 # NOTE: CONF_DIR is "fixed up" by Makefile -- don't rename or change syntax.
@@ -44,16 +45,18 @@ ASCIIDOC = 'asciidoc'
 XSLTPROC = 'xsltproc'
 DBLATEX = 'dblatex'         # pdf generation.
 FOP = 'fop'                 # pdf generation (--fop option).
-W3M = 'w3m'                 # text generation.
-LYNX = 'lynx'               # text generation (if no w3m).
+W3M = 'w3m'                 # primary text file generator.
+LYNX = 'lynx'               # alternate text file generator.
 XMLLINT = 'xmllint'         # Set to '' to disable.
 EPUBCHECK = 'epubcheck'     # Set to '' to disable.
 # External executable default options.
 ASCIIDOC_OPTS = ''
+BACKEND_OPTS = ''
 DBLATEX_OPTS = ''
 FOP_OPTS = ''
+LYNX_OPTS = '-dump'
+W3M_OPTS = '-dump -cols 70 -T text/html -no-graph'
 XSLTPROC_OPTS = ''
-BACKEND_OPTS = ''
 
 ######################################################################
 # End of configuration file parameters.
@@ -144,8 +147,8 @@ def find_executable(file_name):
         result = _find_executable(file_name)
     return result
 
-def write_file(filename, data, mode='w'):
-    f = open(filename, mode)
+def write_file(filename, data, mode='w', encoding='utf-8'):
+    f = codecs.open(filename, mode, encoding)
     try:
         f.write(data)
     finally:
@@ -454,8 +457,8 @@ class A2X(AttrDict):
             if not os.path.isdir(self.destination_dir):
                 die('missing --destination-dir: %s' % self.destination_dir)
             self.destination_dir = os.path.abspath(self.destination_dir)
-            if not self.format in ('chunked','epub','htmlhelp','xhtml'):
-                warning('--destination-dir option is only applicable to HTML based outputs')
+            if not self.format in ('chunked','epub','htmlhelp','xhtml','manpage'):
+                warning('--destination-dir option is only applicable to HTML and manpage based outputs')
         self.resource_dirs = []
         self.resource_files = []
         if self.resource_manifest:
@@ -818,8 +821,8 @@ class A2X(AttrDict):
             shell('"%s" %s --conf-file "%s" -b html4 -a "a2x-format=%s" -o "%s" "%s"' %
                  (self.asciidoc, self.asciidoc_opts, self.asciidoc_conf_file('text.conf'),
                   self.format, html_file, self.asciidoc_file))
-            shell('"%s" -dump "%s" > "%s"' %
-                 (LYNX, html_file, text_file))
+            cmd = '"%s" %s "%s" > "%s"' % (LYNX, LYNX_OPTS, html_file, text_file)
+            shell(cmd)
         else:
             # Use w3m(1).
             self.to_docbook()
@@ -827,8 +830,8 @@ class A2X(AttrDict):
             opts = '%s --output "%s"' % (self.xsltproc_opts, html_file)
             exec_xsltproc(self.xsl_stylesheet(), docbook_file,
                     self.destination_dir, opts)
-            shell('"%s" -cols 70 -dump -T text/html -no-graph "%s" > "%s"' %
-                 (W3M, html_file, text_file))
+            cmd = '"%s" %s "%s" > "%s"' % (W3M, W3M_OPTS, html_file, text_file)
+            shell(cmd)
         if not self.keep_artifacts:
             shell_rm(html_file)
 
@@ -959,4 +962,4 @@ if __name__ == '__main__':
         a2x.load_conf()
         a2x.execute()
     except KeyboardInterrupt:
-        exit(1)
+        sys.exit(1)
